@@ -400,6 +400,10 @@ public:
     return rv;
   }
 
+  virtual PRBool IsFrameOfType(PRUint32 aFlags) const {
+    return !(aFlags & ~nsIFrame::eMathML);
+  }
+
 protected:
   nsMathMLmathBlockFrame() {
     // We should always have a space manager.  Not that things can really try
@@ -491,6 +495,10 @@ public:
     return rv;
   }
 
+  virtual PRBool IsFrameOfType(PRUint32 aFlags) const {
+    return !(aFlags & ~nsIFrame::eMathML);
+  }
+
 protected:
   nsMathMLmathInlineFrame() {}
   virtual ~nsMathMLmathInlineFrame() {}
